@@ -1,5 +1,4 @@
 def change(event, values, window):
-    print(window['-ACTIONS-CHOICE-'].get())
 
     file_browse_input_not_visible = False
     autocomplete_with_current_domain_visible = False
@@ -13,3 +12,10 @@ def change(event, values, window):
     window['-HELPER-INPUT-FILE-BROWSE-'].update(visible=file_browse_input_not_visible)
     window['-HELPER-INPUT-CURRENT-DOMAIN-'].update(visible=autocomplete_with_current_domain_visible)
     window['-HELPER-INPUT-CURRENT-DOMAIN-WITH-ENDPOINT-'].update(visible=autocomplete_with_current_domain_visible)
+    # window['-INPUT-WRAPPER-'].update(visible=False)
+    # _hide_input(window)
+
+
+# def _hide_input(window):
+#     window['-TAG-LIST-'].widget.get_
+
