@@ -4,3 +4,6 @@ class SavedHtml:
         self.username = username
         self.password = password
         self.html = html
+
+    def to_string(self):
+        return f'{self.link} with username:{self.username} and password: {self.password}'
