@@ -2,10 +2,17 @@ import lxml.html as PARSER
 
 
 def get_number_of_match(html, xpath):
+    print(html)
+    print(xpath)
     if html is not None or html != '':
         root = PARSER.fromstring(html)
 
-        exists = root.xpath(xpath)
+        try:
+            exists = root.xpath(xpath)
+        except Exception as e:
+            print(type(e).__name__)
+            return None, None
+
         if exists:
             return exists, len(exists)
         else:
